@@ -230,11 +230,19 @@ lba.mle.logit.AB <- function(obj      ,
 
  iter_ide <- as.numeric(xab$counts[2])
 
+ rescB <- rescaleB(obj,
+                   A,
+                   B)
+
+ colnames(rescB) <- colnames(B)
+ rownames(rescB) <- rownames(B)
+
  results <- list(P,
                  pij,
                  residual,
                  A, 
                  B,
+                 rescB,
                  pk,
                  val_func,
                  iter_ide,
@@ -246,6 +254,7 @@ lba.mle.logit.AB <- function(obj      ,
                      'residual',
                      'A',
                      'B',
+                     'rescB',
                      'pk',
                      'val_func',
                      'iter_ide',
@@ -548,11 +557,19 @@ lba.mle.logit.A <- function(obj       ,
 
  iter_ide <- round(as.numeric(xab$counts[2]/xab$outer.iterations)) + xab$outer.iterations
 
+ rescB <- rescaleB(obj,
+                   A,
+                   B)
+
+ colnames(rescB) <- colnames(B)
+ rownames(rescB) <- rownames(B)
+
  results <- list(P,
                  pij,
                  residual,
                  A, 
                  B,
+                 rescB,
                  pk,
                  val_func,
                  iter_ide,
@@ -563,6 +580,7 @@ lba.mle.logit.A <- function(obj       ,
                      'residual',
                      'A',
                      'B',
+                     'rescB',
                      'pk',
                      'val_func',
                      'iter_ide',
@@ -838,11 +856,19 @@ lba.mle.logit.B <- function(obj       ,
 
  iter_ide <- round(as.numeric(xab$counts[2])/xab$outer.iterations) + xab$outer.iterations
 
+ rescB <- rescaleB(obj,
+                   A,
+                   B)
+
+ colnames(rescB) <- colnames(B)
+ rownames(rescB) <- rownames(B)
+
  results <- list(P,
                  pij,
                  residual,
                  A, 
                  B,
+                 rescB,
                  pk,
                  val_func,
                  iter_ide,
@@ -853,6 +879,7 @@ lba.mle.logit.B <- function(obj       ,
                      'residual',
                      'A',
                      'B',
+                     'rescB',
                      'pk',
                      'val_func',
                      'iter_ide',
